@@ -15,6 +15,7 @@ if (!defined('GSYNC_CONFIG')) {
 }
 
 include_once GSYNC_CONFIG;
+setlocale(LC_ALL, "");
 
 /*
  * MAIN
@@ -165,9 +166,6 @@ class GSyncTop {
 			$topdata = $this->topCollector->ReadLatest();
 			$this->processData($topdata);
 
-			// clear screen
-			$this->scrClear();
-
 			// check if screen size changed
 			$s = $this->scrGetSize();
 			if ($this->scrSize['width'] != $s['width']) {
@@ -306,121 +304,27 @@ class GSyncTop {
 	 * Prints data to the terminal.
 	 */
 	private function scrOverview() {
-		$linesAvail = $this->scrSize['height'] - 8;
+		$linesAvail = $this->scrSize['height'] - 7;
 		$lc = 1;
-		$this->scrPrintAt($lc, 0, "\033[1mgrommunio-sync-top live statistics\033[0m\t\t\t\t\t" . @strftime("%d/%m/%Y %T") . "\n");
+		echo "\e[?25l\e[1;1H";
+		$this->scrPrintAt($lc, 0, sprintf(
+			"grommunio-sync-top live stats (%s, Gromox %s) %s\n",
+			$this->getVersion(),
+			phpversion("mapi"),
+			date("Y-m-d H:i:s")
+		));
 		++$lc;
 
-		$this->scrPrintAt($lc, 0, sprintf("Open connections: %d\t\t\t\tUsers:\t %d\tgrommunio-sync:   %s ", count($this->activeConn), count($this->activeUsers), $this->getVersion()));
+		$this->scrPrintAt($lc, 0, sprintf(
+			"Conn: \e[1m%4d\e[0m open, \e[1m%4d\e[0m push; " .
+			"\e[1m%4d\e[0m users, \e[1m%4d\e[0m devices, \e[1m%4d\e[0m hosts\n",
+			count($this->activeConn),
+			$this->pushConn,
+			count($this->activeUsers),
+			count($this->activeDevices),
+			count($this->activeHosts)
+		));
 		++$lc;
-		$this->scrPrintAt($lc, 0, sprintf("Push connections: %d\t\t\t\tDevices: %d\tPHP-MAPI: %s", $this->pushConn, count($this->activeDevices), phpversion("mapi")));
-		++$lc;
-		$this->scrPrintAt($lc, 0, sprintf("                                                Hosts:\t %d", count($this->activeHosts)));
-		++$lc;
-		++$lc;
-
-		$this->scrPrintAt($lc, 0, "\033[4m" . $this->getLine(['pid' => 'PID', 'ip' => 'IP', 'user' => 'USER', 'command' => 'COMMAND', 'time' => 'TIME', 'devagent' => 'AGENT', 'devid' => 'DEVID', 'addinfo' => 'Additional Information', 'asversion' => 'EAS']) . str_repeat(" ", 20) . "\033[0m");
-		++$lc;
-
-		// print help text if requested
-		$hl = 0;
-		if ($this->helpexpire > $this->currenttime) {
-			$help = $this->scrHelp();
-			$linesAvail -= count($help);
-			$hl = $this->scrSize['height'] - count($help) - 1;
-			foreach ($help as $h) {
-				$this->scrPrintAt($hl, 0, $h);
-				++$hl;
-			}
-		}
-
-		$toPrintActive = $linesAvail;
-		$toPrintOpen = $linesAvail;
-		$toPrintUnknown = $linesAvail;
-		$toPrintTerm = $linesAvail;
-
-		// default view: show all unknown, no terminated and half active+open
-		if (count($this->linesActive) + count($this->linesOpen) + count($this->linesUnknown) > $linesAvail) {
-			$toPrintUnknown = count($this->linesUnknown);
-			$toPrintActive = count($this->linesActive);
-			$toPrintOpen = $linesAvail - $toPrintUnknown - $toPrintActive;
-			$toPrintTerm = 0;
-		}
-
-		if ($this->showOption == self::SHOW_ACTIVE_ONLY) {
-			$toPrintActive = $linesAvail;
-			$toPrintOpen = 0;
-			$toPrintUnknown = 0;
-			$toPrintTerm = 0;
-		}
-
-		if ($this->showOption == self::SHOW_UNKNOWN_ONLY) {
-			$toPrintActive = 0;
-			$toPrintOpen = 0;
-			$toPrintUnknown = $linesAvail;
-			$toPrintTerm = 0;
-		}
-
-		$linesprinted = 0;
-		foreach ($this->linesActive as $time => $l) {
-			if ($linesprinted >= $toPrintActive) {
-				break;
-			}
-
-			$this->scrPrintAt($lc, 0, "\033[01m" . $this->getLine($l) . "\033[0m");
-			++$lc;
-			++$linesprinted;
-		}
-
-		$linesprinted = 0;
-		foreach ($this->linesOpen as $time => $l) {
-			if ($linesprinted >= $toPrintOpen) {
-				break;
-			}
-
-			$this->scrPrintAt($lc, 0, $this->getLine($l));
-			++$lc;
-			++$linesprinted;
-		}
-
-		$linesprinted = 0;
-		foreach ($this->linesUnknown as $time => $l) {
-			if ($linesprinted >= $toPrintUnknown) {
-				break;
-			}
-			$time = intval($time);
-			$color = "0;31m";
-			if (!isset($l['start'])) {
-				$l['start'] = $time;
-			}
-			if ((!isset($l['push']) || $l['push'] == false) && $time - $l["start"] > 30) {
-				$color = "1;31m";
-			}
-			$this->scrPrintAt($lc, 0, "\033[0" . $color . $this->getLine($l) . "\033[0m");
-			++$lc;
-			++$linesprinted;
-		}
-
-		if ($toPrintTerm > 0) {
-			$toPrintTerm = $linesAvail - $lc + 6;
-		}
-
-		$linesprinted = 0;
-		foreach ($this->linesTerm as $time => $l) {
-			if ($linesprinted >= $toPrintTerm) {
-				break;
-			}
-
-			$this->scrPrintAt($lc, 0, "\033[01;30m" . $this->getLine($l) . "\033[0m");
-			++$lc;
-			++$linesprinted;
-		}
-
-		// add the lines used when displaying the help text
-		$lc += $hl;
-		$this->scrPrintAt($lc, 0, "\033[K");
-		++$lc;
-		$this->scrPrintAt($lc, 0, "Colorscheme: \033[01mActive  \033[0mOpen  \033[01;31mUnknown  \033[01;30mTerminated\033[0m");
 
 		// remove old status
 		if ($this->statusexpire < $this->currenttime) {
@@ -460,9 +364,134 @@ class GSyncTop {
 				$str .= "\033[00;31m{$this->status}\033[0m";
 			}
 		}
-		$this->scrPrintAt(5, 0, $str);
+		$this->scrPrintAt($lc, 0, "Action: \033[01m" . $this->action . "\033[0m\n");
+		++$lc;
+		$this->scrPrintAt($lc, 0, $str . "\n");
+		++$lc;
+		$header = $this->getLine(['pid' => 'PID', 'ip' => 'ADDRESS', 'user' => 'USER', 'command' => 'COMMAND', 'time' => 'TIME', 'devagent' => 'AGENT', 'devid' => 'DEVID', 'addinfo' => 'Additional Information', 'asversion' => 'EAS']);
+		$this->scrPrintAt($lc, 0, "\033[7m" . $header . str_repeat(" ", $this->scrSize['width'] - ($this->scrSize['width'] > strlen($header) ? strlen($header) : 0)) . "\033[0m\n");
+		++$lc;
 
-		$this->scrPrintAt(4, 0, "Action: \033[01m" . $this->action . "\033[0m");
+		if ($linesAvail < 1) {
+			echo "Terminal too small, no room to display any useful information.";
+			++$lc;
+
+			return;
+		}
+
+		// print help text if requested
+		$help = false;
+		if ($this->helpexpire > $this->currenttime) {
+			$help = $this->scrHelp();
+			$linesAvail -= (count($help) + 1);
+		}
+
+		$toPrintActive = $linesAvail;
+		$toPrintOpen = $linesAvail;
+		$toPrintUnknown = $linesAvail;
+		$toPrintTerm = $linesAvail;
+
+		// default view: show all unknown, no terminated and half active+open
+		if (count($this->linesActive) + count($this->linesOpen) + count($this->linesUnknown) > $linesAvail) {
+			$toPrintUnknown = count($this->linesUnknown);
+			$toPrintActive = count($this->linesActive);
+			$toPrintOpen = $linesAvail - $toPrintUnknown - $toPrintActive;
+			$toPrintTerm = 0;
+		}
+
+		if ($this->showOption == self::SHOW_ACTIVE_ONLY) {
+			$toPrintActive = $linesAvail;
+			$toPrintOpen = 0;
+			$toPrintUnknown = 0;
+			$toPrintTerm = 0;
+		}
+
+		if ($this->showOption == self::SHOW_UNKNOWN_ONLY) {
+			$toPrintActive = 0;
+			$toPrintOpen = 0;
+			$toPrintUnknown = $linesAvail;
+			$toPrintTerm = 0;
+		}
+
+		$linesprinted = 0;
+		foreach ($this->linesActive as $time => $l) {
+			if ($linesprinted >= $toPrintActive) {
+				break;
+			}
+
+			$this->scrPrintAt($lc, 0, "\033[01m" . $this->getLine($l) . "\033[0m\n");
+			++$lc;
+			++$linesprinted;
+		}
+
+		$linesprinted = 0;
+		foreach ($this->linesOpen as $time => $l) {
+			if ($linesprinted >= $toPrintOpen) {
+				break;
+			}
+
+			$this->scrPrintAt($lc, 0, $this->getLine($l) . "\n");
+			++$lc;
+			++$linesprinted;
+		}
+
+		$linesprinted = 0;
+		foreach ($this->linesUnknown as $time => $l) {
+			if ($linesprinted >= $toPrintUnknown) {
+				break;
+			}
+			$time = intval($time);
+			$color = "0;31m";
+			if (!isset($l['start'])) {
+				$l['start'] = $time;
+			}
+			if ((!isset($l['push']) || $l['push'] == false) && $time - $l["start"] > 30) {
+				$color = "1;31m";
+			}
+			$this->scrPrintAt($lc, 0, "\033[0" . $color . $this->getLine($l) . "\033[0m\n");
+			++$lc;
+			++$linesprinted;
+		}
+
+		if ($toPrintTerm > 0) {
+			$toPrintTerm = $linesAvail - $lc + 5;
+		}
+
+		$linesprinted = 0;
+		foreach ($this->linesTerm as $time => $l) {
+			if ($linesprinted >= $toPrintTerm) {
+				break;
+			}
+
+			$this->scrPrintAt($lc, 0, "\033[01;30m" . $this->getLine($l) . "\033[0m\n");
+			++$lc;
+			++$linesprinted;
+		}
+
+		// add the lines used when displaying the help text
+		if ($help !== false) {
+			while ($lc < $linesAvail + 7) {
+				$this->scrPrintAt($lc, 0, "\033[K\n");
+				++$lc;
+			}
+			if ($linesAvail < 1) {
+				$this->scrPrintAt($lc, 0, "Can't display help text, terminal has not enough lines. Use -h or --help to see help information. \n");
+				++$lc;
+			}
+			else {
+				foreach ($help as $h) {
+					$this->scrPrintAt($lc, 0, $h . "\n");
+					++$lc;
+				}
+			}
+		}
+		$this->scrPrintAt($lc, 0, "\033[K\n");
+		++$lc;
+		$this->scrPrintAt($lc, 0, "Colorscheme: \033[01mActive  \033[0mOpen  \033[01;31mUnknown  \033[01;30mTerminated\033[0m");
+		/* Clear rest of area */
+		echo "\e[J";
+		/* Reposition cursor to Action: line */
+		printf("\e[3;%dH\e[?25h", 9 + strlen($this->action));
 	}
 
 	/**
@@ -625,7 +654,7 @@ class GSyncTop {
 	 * @return string
 	 */
 	public function UsageInstructions() {
-		$help = "Usage:\n\tgrommunio-sync-top.php\n\n" .
+		$help = "Usage:\n\tgrommunio-sync-top\n\n" .
 				"  grommunio-sync-top is a live top-like overview of what grommunio-sync is doing. It does not have specific command line options.\n\n" .
 				"  When grommunio-sync-top is running you can specify certain actions and options which can be executed (listed below).\n" .
 				"  This help information can also be shown inside grommunio-sync-top by hitting 'help' or 'h'.\n\n";
@@ -647,22 +676,22 @@ class GSyncTop {
 		$h = [];
 		$secs = $this->helpexpire - $this->currenttime;
 		$h[] = "Actions supported by grommunio-sync-top (help page still displayed for " . $secs . "secs)";
-		$h[] = "  " . $this->scrAsBold("Action") . "\t\t" . $this->scrAsBold("Comment");
-		$h[] = "  " . $this->scrAsBold("h") . " or " . $this->scrAsBold("help") . "\t\tDisplays this information.";
-		$h[] = "  " . $this->scrAsBold("q") . ", " . $this->scrAsBold("quit") . " or " . $this->scrAsBold(":q") . "\t\tExits grommunio-sync-top.";
-		$h[] = "  " . $this->scrAsBold("w") . " or " . $this->scrAsBold("wide") . "\t\tTries not to truncate data. Automatically done if more than 180 columns available.";
-		$h[] = "  " . $this->scrAsBold("f:VAL") . " or " . $this->scrAsBold("filter:VAL") . "\tOnly display connections which contain VAL. This value is case-insensitive.";
-		$h[] = "  " . $this->scrAsBold("f:") . " or " . $this->scrAsBold("filter:") . "\t\tWithout a search word: resets the filter.";
-		$h[] = "  " . $this->scrAsBold("l:STR") . " or " . $this->scrAsBold("log:STR") . "\tIssues 'less +G' on the logfile, after grepping on the optional STR.";
-		$h[] = "  " . $this->scrAsBold("t:STR") . " or " . $this->scrAsBold("tail:STR") . "\tIssues 'tail -f' on the logfile, grepping for optional STR.";
-		$h[] = "  " . $this->scrAsBold("e:STR") . " or " . $this->scrAsBold("error:STR") . "\tIssues 'tail -f' on the error logfile, grepping for optional STR.";
-		$h[] = "  " . $this->scrAsBold("r") . " or " . $this->scrAsBold("reset") . "\t\tResets 'wide' or 'filter'.";
-		$h[] = "  " . $this->scrAsBold("o:") . " or " . $this->scrAsBold("option:") . "\t\tSets display options. Valid options specified below";
-		$h[] = "  " . $this->scrAsBold("  p") . " or " . $this->scrAsBold("push") . "\t\tLists/not lists active and open push connections.";
-		$h[] = "  " . $this->scrAsBold("  a") . " or " . $this->scrAsBold("action") . "\t\tLists only active connections.";
-		$h[] = "  " . $this->scrAsBold("  u") . " or " . $this->scrAsBold("unknown") . "\tLists only unknown connections.";
-		$h[] = "  " . $this->scrAsBold("  10") . " or " . $this->scrAsBold("20") . "\t\tLists terminated connections for 10 or 20 seconds. Any other number can be used.";
-		$h[] = "  " . $this->scrAsBold("  d") . " or " . $this->scrAsBold("default") . "\tUses default options";
+		$h[] = "  " . $this->scrAsBold("Action") . "                " . $this->scrAsBold("Comment");
+		$h[] = "  " . $this->scrAsBold("h") . " or " . $this->scrAsBold("help") . "             Displays this information.";
+		$h[] = "  " . $this->scrAsBold("q") . ", " . $this->scrAsBold("quit") . " or " . $this->scrAsBold(":q") . "         Exits grommunio-sync-top.";
+		$h[] = "  " . $this->scrAsBold("w") . " or " . $this->scrAsBold("wide") . "             Tries not to truncate data. Automatically done if more than 180 columns available.";
+		$h[] = "  " . $this->scrAsBold("f:VAL") . " or " . $this->scrAsBold("filter:VAL") . "   Only display connections which contain VAL. This value is case-insensitive.";
+		$h[] = "  " . $this->scrAsBold("f:") . " or " . $this->scrAsBold("filter:") . "         Without a search word: resets the filter.";
+		$h[] = "  " . $this->scrAsBold("l:STR") . " or " . $this->scrAsBold("log:STR") . "      Issues 'less +G' on the logfile, after grepping on the optional STR.";
+		$h[] = "  " . $this->scrAsBold("t:STR") . " or " . $this->scrAsBold("tail:STR") . "     Issues 'tail -f' on the logfile, grepping for optional STR.";
+		$h[] = "  " . $this->scrAsBold("e:STR") . " or " . $this->scrAsBold("error:STR") . "    Issues 'tail -f' on the error logfile, grepping for optional STR.";
+		$h[] = "  " . $this->scrAsBold("r") . " or " . $this->scrAsBold("reset") . "            Resets 'wide' or 'filter'.";
+		$h[] = "  " . $this->scrAsBold("o:") . " or " . $this->scrAsBold("option:") . "         Sets display options. Valid options specified below";
+		$h[] = "  " . $this->scrAsBold("  p") . " or " . $this->scrAsBold("push") . "           Lists/not lists active and open push connections.";
+		$h[] = "  " . $this->scrAsBold("  a") . " or " . $this->scrAsBold("action") . "         Lists only active connections.";
+		$h[] = "  " . $this->scrAsBold("  u") . " or " . $this->scrAsBold("unknown") . "        Lists only unknown connections.";
+		$h[] = "  " . $this->scrAsBold("  10") . " or " . $this->scrAsBold("20") . "            Lists terminated connections for 10 or 20 seconds. Any other number can be used.";
+		$h[] = "  " . $this->scrAsBold("  d") . " or " . $this->scrAsBold("default") . "        Uses default options";
 
 		return $h;
 	}
@@ -690,7 +719,7 @@ class GSyncTop {
 			return "";
 		}
 		if ($this->wide === true) {
-			return sprintf("%s%s%s%s%s%s%s%s%s", $this->ptStr($l['pid'], 7), $this->ptStr($l['ip'], 16), $this->ptStr($l['user'], 24), $this->ptStr($l['command'], 16), $this->ptStr($this->sec2min($l['time']), 8), $this->ptStr($l['devagent'], 28), $this->ptStr($l['asversion'], 5), $this->ptStr($l['devid'], 33, true), $l['addinfo']);
+			return sprintf("%s%s%s%s%s%s%s%s%s", $this->ptStr($l['pid'], 7), $this->ptStr($l['ip'], 40), $this->ptStr($l['user'], 24), $this->ptStr($l['command'], 16), $this->ptStr($this->sec2min($l['time']), 8), $this->ptStr($l['devagent'], 28), $this->ptStr($l['asversion'], 5), $this->ptStr($l['devid'], 33, true), $l['addinfo']);
 		}
 
 		return sprintf("%s%s%s%s%s%s%s%s%s", $this->ptStr($l['pid'], 7), $this->ptStr($l['ip'], 16), $this->ptStr($l['user'], 8), $this->ptStr($l['command'], 8), $this->ptStr($this->sec2min($l['time']), 6), $this->ptStr($l['devagent'], 20), $this->ptStr($l['asversion'], 5), $this->ptStr($l['devid'], 12, true), $l['addinfo']);
@@ -780,6 +809,6 @@ class GSyncTop {
 	 * @param string $text to be printed
 	 */
 	private function scrPrintAt($row, $col, $text = "") {
-		echo "\033[" . $row . ";" . $col . "H" . $text;
+		echo "\033[" . $row . ";" . $col . "H" . preg_replace("/\n/", "\e[K\n", $text);
 	}
 }
