@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * Core functionalities
  */
@@ -66,7 +66,7 @@ class GSync {
 	// Latest supported State version
 	public const STATE_VERSION = IStateMachine::STATEVERSION_02;
 
-	// Versions 1.0, 2.0, 2.1 and 2.5 are deprecated (ZP-604)
+	// Versions 1.0, 2.0, 2.1 and 2.5 are deprecated
 	private static $supportedASVersions = [
 		self::ASV_12,
 		self::ASV_121,
@@ -392,6 +392,37 @@ class GSync {
 		return GSync::$stateMachine;
 	}
 
+	/**
+	 * Marks an arbitrary ID for a user and device for 2 seconds.
+	 *
+	 * @param $id $mixed
+	 */
+	public static function ReplyCatchMark($id) {
+		$k = sprintf("grommunio-sync:rb-%s-%s-%s", Request::GetAuthUserString(), Request::GetDeviceID(), $id);
+		$r = GSync::GetRedis();
+		if ($r) {
+			$r->setKey($k, true, 2); // 2 sec timeout!
+		}
+	}
+
+	/**
+	 * Returns if an arbitrary ID for a user and device was marked in the last 2 seconds.
+	 *
+	 * @param $id $mixed
+	 *
+	 * @return bool
+	 */
+	public static function ReplyCatchHasChange($id) {
+		$k = sprintf("grommunio-sync:rb-%s-%s-%s", Request::GetAuthUserString(), Request::GetDeviceID(), $id);
+
+		$r = GSync::GetRedis();
+		if ($r) {
+			return $r->get()->exists($k);
+		}
+
+		return false;
+	}
+
 	/**
 	 * Returns the Redis object.
 	 *
@@ -582,7 +613,7 @@ class GSync {
 
 	/**
 	 * Initializes the SyncObjects for additional folders on demand.
-	 * Uses DeviceManager->BuildSyncFolderObject() to do patching required for ZP-907.
+	 * Uses DeviceManager->BuildSyncFolderObject() to do patching.
 	 *
 	 * @return array
 	 */
