@@ -556,6 +556,7 @@ define("SYNC_AIRSYNCBASE_ALTITUDE", "AirSyncBase:Altitude"); // Since 16.0
 define("SYNC_AIRSYNCBASE_ALTITUDEACCURACY", "AirSyncBase:AltitudeAccuracy"); // Since 16.0
 define("SYNC_AIRSYNCBASE_LOCATIONURI", "AirSyncBase:LocationUri"); // Since 16.0
 define("SYNC_AIRSYNCBASE_INSTANCEID", "AirSyncBase:InstanceId"); // Since 16.0
+define("SYNC_AIRSYNCBASE_INSTANCEID_DELETE", "AirSyncBase:InstanceId:Delete"); // Internal to transport delete request
 
 // Code Page 18: Settings, Since 12.0
 define("SYNC_SETTINGS_SETTINGS", "Settings:Settings");
@@ -765,6 +766,7 @@ define("SYNC_FILTERTYPE_1MONTH", 5);
 define("SYNC_FILTERTYPE_3MONTHS", 6);
 define("SYNC_FILTERTYPE_6MONTHS", 7);
 define("SYNC_FILTERTYPE_INCOMPLETETASKS", 8);
+define("SYNC_FILTERTYPE_DISABLE", 999);
 
 define("SYNC_TRUNCATION_HEADERS", 0);
 define("SYNC_TRUNCATION_512B", 1);
@@ -793,6 +795,9 @@ define("SYNC_PROVISION_RWSTATUS_OK", 1);
 define("SYNC_PROVISION_RWSTATUS_PENDING", 2);
 define("SYNC_PROVISION_RWSTATUS_REQUESTED", 4);
 define("SYNC_PROVISION_RWSTATUS_WIPED", 8);
+define("SYNC_PROVISION_RWSTATUS_PENDING_ACCOUNT_ONLY", 16);
+define("SYNC_PROVISION_RWSTATUS_REQUESTED_ACCOUNT_ONLY", 32);
+define("SYNC_PROVISION_RWSTATUS_WIPED_ACCOUNT_ONLY", 64);
 
 define("SYNC_STATUS_SUCCESS", 1);
 define("SYNC_STATUS_INVALIDSYNCKEY", 3);
