@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * This file handles streaming of WBXML SyncObjects. It must be subclassed so
  * the internals of the object can be specified via $mapping. Basically we
@@ -97,7 +97,7 @@ class Streamer implements JsonSerializable {
 				if (isset($map[self::STREAMER_ARRAY])) {
 					WBXMLDecoder::ResetInWhile("decodeArray");
 					while (WBXMLDecoder::InWhile("decodeArray")) {
-						$streamertype = false;
+						$streamertype = $map[self::STREAMER_TYPE] ?? false;
 						// do not get start tag for an array without a container
 						if (!(isset($map[self::STREAMER_PROP]) && $map[self::STREAMER_PROP] == self::STREAMER_TYPE_NO_CONTAINER)) {
 							// are there multiple possibilities for element encapsulation tags?
@@ -165,7 +165,7 @@ class Streamer implements JsonSerializable {
 					if (isset($map[self::STREAMER_TYPE])) {
 						// Complex type, decode recursively
 						if ($map[self::STREAMER_TYPE] == self::STREAMER_TYPE_DATE || $map[self::STREAMER_TYPE] == self::STREAMER_TYPE_DATE_DASHES) {
-							$decoded = Utils::parseDate($decoder->getElementContent());
+							$decoded = Utils::ParseDate($decoder->getElementContent());
 							if (!$decoder->getElementEndTag()) {
 								return false;
 							}
@@ -333,7 +333,7 @@ class Streamer implements JsonSerializable {
 
 					if (isset($map[self::STREAMER_TYPE]) && ($map[self::STREAMER_TYPE] == self::STREAMER_TYPE_DATE || $map[self::STREAMER_TYPE] == self::STREAMER_TYPE_DATE_DASHES)) {
 						if ($this->{$map[self::STREAMER_VAR]} != 0) { // don't output 1-1-1970
-							$encoder->content($this->formatDate($this->{$map[self::STREAMER_VAR]}, $map[self::STREAMER_TYPE]));
+							$encoder->content(Utils::FormatDate($this->{$map[self::STREAMER_VAR]}, $map[self::STREAMER_TYPE]));
 						}
 					}
 					elseif (isset($map[self::STREAMER_TYPE]) && $map[self::STREAMER_TYPE] == self::STREAMER_TYPE_HEX) {
@@ -431,9 +431,8 @@ class Streamer implements JsonSerializable {
 	 *
 	 * Serializes the object to a value that can be serialized natively by json_encode()
 	 *
-	 * @return array
 	 */
-	public function jsonSerialize() {
+	public function jsonSerialize(): mixed {
 		$data = [];
 		foreach ($this->mapping as $k => $v) {
 			if (isset($this->{$v[self::STREAMER_VAR]})) {
@@ -463,31 +462,4 @@ class Streamer implements JsonSerializable {
 			}
 		}
 	}
-
-	/*----------------------------------------------------------------------------------------------------------
-	 * Private methods for conversion
-	 */
-
-	/**
-	 * Formats a timestamp
-	 * Oh yeah, this is beautiful. Exchange outputs date fields differently in calendar items
-	 * and emails. We could just always send one or the other, but unfortunately nokia's 'Mail for
-	 *  exchange' depends on this quirk. So we have to send a different date type depending on where
-	 * it's used. Sigh.
-	 *
-	 * @param int $ts
-	 * @param int $type
-	 *
-	 * @return string
-	 */
-	private function formatDate($ts, $type) {
-		if ($type == self::STREAMER_TYPE_DATE) {
-			return gmstrftime("%Y%m%dT%H%M%SZ", $ts);
-		}
-		if ($type == self::STREAMER_TYPE_DATE_DASHES) {
-			return gmstrftime("%Y-%m-%dT%H:%M:%S.000Z", $ts);
-		}
-		// fallback to dashes (should never be reached)
-		return gmstrftime("%Y-%m-%dT%H:%M:%S.000Z", $ts);
-	}
 }
