@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2023 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * This is basically a list of synched folders with its respective
  * SyncParameters, while some additional parameters which are not stored
@@ -521,8 +521,15 @@ class SyncCollections implements Iterator {
 
 				// check if the folder stat changed since the last sync, if so generate a change for it (only on first run)
 				$currentFolderStat = GSync::GetBackend()->GetFolderStat($store, $backendFolderId);
-				if ($this->waitingTime == 0 && GSync::GetBackend()->HasFolderStats() && $currentFolderStat !== false && $spa->IsExporterRunRequired($currentFolderStat, true)) {
-					$this->changes[$spa->GetFolderId()] = 1;
+				if ($this->waitingTime == 0 &&
+					GSync::GetBackend()->HasFolderStats() &&
+					$currentFolderStat !== false &&
+					$spa->IsExporterRunRequired($currentFolderStat, true) &&
+					!$this->CountChange($spa->GetFolderId()) &&
+					array_key_exists($spa->GetFolderId(), $this->changes)
+				) {
+					SLog::Write(LOGLEVEL_DEBUG, sprintf("SyncCollections->CheckForChanges(): Initial check indicates changes on folder '%s', but they are not relevant", $spa->GetFolderId()));
+					unset($this->changes[$spa->GetFolderId()]);
 				}
 			}
 		}
@@ -853,42 +860,36 @@ class SyncCollections implements Iterator {
 	/**
 	 * Rewind the Iterator to the first element.
 	 */
-	public function rewind() {
-		return reset($this->collections);
+	public function rewind(): void {
+		reset($this->collections);
 	}
 
 	/**
 	 * Returns the current element.
-	 *
-	 * @return mixed
 	 */
-	public function current() {
+	public function current(): mixed {
 		return current($this->collections);
 	}
 
 	/**
 	 * Return the key of the current element.
-	 *
-	 * @return scalar on success, or NULL on failure
 	 */
-	public function key() {
+	public function key(): mixed {
 		return key($this->collections);
 	}
 
 	/**
 	 * Move forward to next element.
 	 */
-	public function next() {
-		return next($this->collections);
+	public function next(): void {
+		next($this->collections);
 	}
 
 	/**
 	 * Checks if current position is valid.
-	 *
-	 * @return bool
 	 */
-	public function valid() {
-		return key($this->collections) != null && key($this->collections) != false;
+	public function valid(): bool {
+		return key($this->collections) !== null && key($this->collections) !== false;
 	}
 
 	/**
