@@ -2,11 +2,11 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2013,2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  */
 
 /**
- * MAPI to AS mapping class.
+ * MAPI utility functions.
  */
 class MAPIUtils {
 	/**
@@ -530,17 +530,6 @@ class MAPIUtils {
 		return SYNC_FOLDER_TYPE_OTHER;
 	}
 
-	public static function GetSignedAttachmentRestriction() {
-		return [
-			RES_PROPERTY,
-			[
-				RELOP => RELOP_EQ,
-				ULPROPTAG => PR_ATTACH_MIME_TAG,
-				VALUE => [PR_ATTACH_MIME_TAG => 'multipart/signed'],
-			],
-		];
-	}
-
 	/**
 	 * Calculates the native body type of a message using available properties. Refer to oxbbody.
 	 *
@@ -579,14 +568,14 @@ class MAPIUtils {
 			($messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_HTML] == MAPI_E_NOT_FOUND)) {
-			return SYNC_BODYPREFERENCE_RTF;
+			return SYNC_BODYPREFERENCE_PLAIN;
 		}
 		if ( // 4
 			($messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_HTML] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			$messageprops[PR_RTF_IN_SYNC]) {
-			return SYNC_BODYPREFERENCE_RTF;
+			return SYNC_BODYPREFERENCE_PLAIN;
 		}
 		if ( // 5
 			($messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
@@ -599,7 +588,7 @@ class MAPIUtils {
 			($messageprops[PR_RTF_COMPRESSED] != MAPI_E_NOT_FOUND || $messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_HTML] != MAPI_E_NOT_FOUND || $messageprops[PR_HTML] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			$messageprops[PR_RTF_IN_SYNC]) {
-			return SYNC_BODYPREFERENCE_RTF;
+			return SYNC_BODYPREFERENCE_PLAIN;
 		}
 		if ( // 7
 			($messageprops[PR_RTF_COMPRESSED] != MAPI_E_NOT_FOUND || $messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
@@ -611,7 +600,7 @@ class MAPIUtils {
 			($messageprops[PR_BODY] != MAPI_E_NOT_FOUND || $messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_RTF_COMPRESSED] != MAPI_E_NOT_FOUND || $messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			$messageprops[PR_RTF_IN_SYNC]) {
-			return SYNC_BODYPREFERENCE_RTF;
+			return SYNC_BODYPREFERENCE_PLAIN;
 		}
 		if ( // 9.1
 			($messageprops[PR_BODY] != MAPI_E_NOT_FOUND || $messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
@@ -623,7 +612,7 @@ class MAPIUtils {
 			($messageprops[PR_RTF_COMPRESSED] != MAPI_E_NOT_FOUND || $messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_ENOUGH_MEMORY) &&
 			($messageprops[PR_BODY] == MAPI_E_NOT_FOUND) &&
 			($messageprops[PR_HTML] == MAPI_E_NOT_FOUND)) {
-			return SYNC_BODYPREFERENCE_RTF;
+			return SYNC_BODYPREFERENCE_PLAIN;
 		}
 		if ( // 9.3
 			($messageprops[PR_BODY] != MAPI_E_NOT_FOUND || $messageprops[PR_BODY] == MAPI_E_NOT_ENOUGH_MEMORY) &&
@@ -637,6 +626,7 @@ class MAPIUtils {
 			($messageprops[PR_RTF_COMPRESSED] == MAPI_E_NOT_FOUND)) {
 			return SYNC_BODYPREFERENCE_HTML;
 		}
+
 		// 10
 		return SYNC_BODYPREFERENCE_PLAIN;
 	}
@@ -678,6 +668,10 @@ class MAPIUtils {
 			PR_SENT_REPRESENTING_NAME,
 			PR_SENT_REPRESENTING_ENTRYID,
 			PR_SENT_REPRESENTING_SEARCH_KEY,
+			PR_SENT_REPRESENTING_EMAIL_ADDRESS,
+			PR_SENT_REPRESENTING_SMTP_ADDRESS,
+			PR_SENT_REPRESENTING_ADDRTYPE,
+			PR_CLIENT_SUBMIT_TIME,
 			PR_MESSAGE_FLAGS,
 		]);
 		$read = $props[PR_MESSAGE_FLAGS] & MSGFLAG_READ;
@@ -698,29 +692,7 @@ class MAPIUtils {
 				$att = mapi_message_openattach($mapimessage, $attnum);
 				$data = mapi_openproperty($att, PR_ATTACH_DATA_BIN);
 				mapi_message_deleteattach($mapimessage, $attnum);
-				// also copy recipients because they are lost after mapi_inetmapi_imtomapi
-				$recipienttable = mapi_message_getrecipienttable($mapimessage);
-				$messageRecipients = mapi_table_queryallrows($recipienttable, [
-					PR_ENTRYID,
-					PR_SEARCH_KEY,
-					PR_ROWID,
-					PR_DISPLAY_NAME,
-					PR_DISPLAY_TYPE,
-					PR_DISPLAY_TYPE_EX,
-					PR_ADDRTYPE,
-					PR_EMAIL_ADDRESS,
-					PR_SMTP_ADDRESS,
-					PR_OBJECT_TYPE,
-					PR_RECIPIENT_FLAGS,
-					PR_RECIPIENT_TYPE,
-					PR_RECIPIENT_TRACKSTATUS,
-					PR_RECIPIENT_TRACKSTATUS_TIME,
-					PR_CREATION_TIME,
-				]);
 				mapi_inetmapi_imtomapi($session, $store, $addressBook, $mapimessage, $data, ["parse_smime_signed" => 1]);
-				if (!empty($messageRecipients)) {
-					mapi_message_modifyrecipients($mapimessage, MODRECIP_ADD, $messageRecipients);
-				}
 				SLog::Write(LOGLEVEL_DEBUG, "Convert a smime signed message to a normal message.");
 			}
 			$mprops = mapi_getprops($mapimessage, [PR_MESSAGE_FLAGS]);
@@ -732,191 +704,14 @@ class MAPIUtils {
 				PR_SENT_REPRESENTING_NAME => $props[PR_SENT_REPRESENTING_NAME],
 				PR_SENT_REPRESENTING_ENTRYID => $props[PR_SENT_REPRESENTING_ENTRYID],
 				PR_SENT_REPRESENTING_SEARCH_KEY => $props[PR_SENT_REPRESENTING_SEARCH_KEY],
+				PR_SENT_REPRESENTING_EMAIL_ADDRESS => $props[PR_SENT_REPRESENTING_EMAIL_ADDRESS] ?? '',
+				PR_SENT_REPRESENTING_SMTP_ADDRESS => $props[PR_SENT_REPRESENTING_SMTP_ADDRESS] ?? '',
+				PR_SENT_REPRESENTING_ADDRTYPE => $props[PR_SENT_REPRESENTING_ADDRTYPE] ?? 'SMTP',
+				PR_CLIENT_SUBMIT_TIME => $props[PR_CLIENT_SUBMIT_TIME] ?? time(),
 				// mark the message as read if the main message has read flag
 				PR_MESSAGE_FLAGS => $read ? $mprops[PR_MESSAGE_FLAGS] | MSGFLAG_READ : $mprops[PR_MESSAGE_FLAGS],
 			]);
 		}
 		// TODO check if we need to do this for encrypted (and signed?) message as well
 	}
-
-	/**
-	 * Compares two entryIds. It is possible to have two different entryIds that should match as they
-	 * represent the same object (in multiserver environments).
-	 *
-	 * @param string $entryId1
-	 * @param string $entryId2
-	 *
-	 * @return bool
-	 */
-	public static function CompareEntryIds($entryId1, $entryId2) {
-		if (!is_string($entryId1) || !is_string($entryId2)) {
-			return false;
-		}
-
-		if ($entryId1 === $entryId2) {
-			// if normal comparison succeeds then we can directly say that entryids are same
-			return true;
-		}
-
-		$eid1 = self::createEntryIdObj($entryId1);
-		$eid2 = self::createEntryIdObj($entryId2);
-
-		if ($eid1['length'] != $eid2['length'] ||
-				$eid1['abFlags'] != $eid2['abFlags'] ||
-				$eid1['version'] != $eid2['version'] ||
-				$eid1['type'] != $eid2['type']) {
-			return false;
-		}
-
-		if ($eid1['name'] == 'EID_V0') {
-			if ($eid1['length'] < $eid1['min_length'] || $eid1['id'] != $eid2['id']) {
-				return false;
-			}
-		}
-		elseif ($eid1['length'] < $eid1['min_length'] || $eid1['uniqueId'] != $eid2['uniqueId']) {
-			return false;
-		}
-
-		return true;
-	}
-
-	/**
-	 * Creates an object that has split up all the components of an entryID.
-	 *
-	 * @param string $entryid Entryid
-	 *
-	 * @return object EntryID object
-	 */
-	private static function createEntryIdObj($entryid) {
-		// check if we are dealing with old or new object entryids
-		return (substr($entryid, 40, 8) == '00000000') ? self::getEID_V0Version($entryid) : self::getEIDVersion($entryid);
-	}
-
-	/**
-	 * The entryid from the begin of zarafa till 5.20.
-	 *
-	 * @param string $entryid
-	 *
-	 * @return object EntryID object
-	 */
-	private static function getEID_V0Version($entryid) {
-		// always make entryids in uppercase so comparison will be case insensitive
-		$entryId = strtoupper($entryid);
-
-		$res = [
-			'abFlags' => '',  // BYTE[4],  4 bytes,  8 hex characters
-			'guid' => '',  // GUID,    16 bytes, 32 hex characters
-			'version' => '',  // ULONG,    4 bytes,  8 hex characters
-			'type' => '',  // ULONG,    4 bytes,  8 hex characters
-			'id' => '',  // ULONG,    4 bytes,  8 hex characters
-			'server' => '',  // CHAR,    variable length
-			'padding' => '',  // TCHAR[3], 4 bytes,  8 hex characters (up to 4 bytes)
-		];
-
-		$res['length'] = strlen($entryId);
-		$offset = 0;
-
-		// First determine padding, and remove if from the entryId
-		$res['padding'] = self::getPadding($entryId);
-		$entryId = substr($entryId, 0, strlen($entryId) - strlen($res['padding']));
-
-		$res['abFlags'] = substr($entryId, $offset, 8);
-		$offset = +8;
-
-		$res['guid'] = substr($entryId, $offset, 32);
-		$offset += 32;
-
-		$res['version'] = substr($entryId, $offset, 8);
-		$offset += 8;
-
-		$res['type'] = substr($entryId, $offset, 8);
-		$offset += 8;
-
-		$res['id'] = substr($entryId, $offset, 8);
-		$offset += 8;
-
-		$res['server'] = substr($entryId, $offset);
-
-		$res['min_length'] = 64;
-		$res['name'] = 'EID_V0';
-
-		return $res;
-	}
-
-	/**
-	 * Entryid from version 6.
-	 *
-	 * @param string $entryid
-	 *
-	 * @return null[]|number[]|string[]
-	 */
-	private static function getEIDVersion($entryid) {
-		// always make entryids in uppercase so comparison will be case insensitive
-		$entryId = strtoupper($entryid);
-
-		$res = [
-			'abFlags' => '',  // BYTE[4],  4 bytes,  8 hex characters
-			'guid' => '',  // GUID,    16 bytes, 32 hex characters
-			'version' => '',  // ULONG,    4 bytes,  8 hex characters
-			'type' => '',  // ULONG,    4 bytes,  8 hex characters
-			'uniqueId' => '',  // ULONG,   16 bytes,  32 hex characters
-			'server' => '',  // CHAR,    variable length
-			'padding' => '',  // TCHAR[3], 4 bytes,  8 hex characters (up to 4 bytes)
-		];
-
-		$res['length'] = strlen($entryId);
-		$offset = 0;
-
-		// First determine padding, and remove if from the entryId
-		$res['padding'] = self::getPadding($entryId);
-		$entryId = substr($entryId, 0, strlen($entryId) - strlen($res['padding']));
-
-		$res['abFlags'] = substr($entryId, $offset, 8);
-		$offset = +8;
-
-		$res['guid'] = substr($entryId, $offset, 32);
-		$offset += 32;
-
-		$res['version'] = substr($entryId, $offset, 8);
-		$offset += 8;
-
-		$res['type'] = substr($entryId, $offset, 8);
-		$offset += 8;
-
-		$res['uniqueId'] = substr($entryId, $offset, 32);
-		$offset += 32;
-
-		$res['server'] = substr($entryId, $offset);
-
-		$res['min_length'] = 88;
-		$res['name'] = 'EID';
-
-		return $res;
-	}
-
-	/**
-	 * Detect padding (max 3 bytes) from the entryId.
-	 *
-	 * @param string $entryId
-	 *
-	 * @return string
-	 */
-	private static function getPadding($entryId) {
-		$len = strlen($entryId);
-		$padding = '';
-		$offset = 0;
-
-		for ($iterations = 4; $iterations > 0; --$iterations) {
-			if (substr($entryId, $len - ($offset + 2), $len - $offset) == '00') {
-				$padding .= '00';
-				$offset += 2;
-			}
-			else {
-				// if non-null character found then break the loop
-				break;
-			}
-		}
-
-		return $padding;
-	}
 }
