@@ -2,7 +2,7 @@
 /*
  * SPDX-License-Identifier: AGPL-3.0-only
  * SPDX-FileCopyrightText: Copyright 2007-2016 Zarafa Deutschland GmbH
- * SPDX-FileCopyrightText: Copyright 2020-2022 grommunio GmbH
+ * SPDX-FileCopyrightText: Copyright 2020-2024 grommunio GmbH
  *
  * Provides the GETHIERARCHY command
  */
@@ -19,7 +19,7 @@ class GetHierarchy extends RequestProcessor {
 	public function Handle($commandCode) {
 		try {
 			$folders = self::$backend->GetHierarchy();
-			if (!$folders || empty($folders)) {
+			if (!$folders || count($folders) == 0) {
 				throw new StatusException("GetHierarchy() did not return any data.");
 			}
 
